Pelican
#######

Pelican is a simple weblog generator, written in `Python <http://www.python.org/>`_.

* Write your weblog entries directly with your editor of choice (vim!) and
  directly in `reStructuredText <http://docutils.sourceforge.net/rst.html>`_, or `Markdown <http://daringfireball.net/projects/markdown/>`_.
* A simple cli-tool to (re)generate the weblog.
* Easy to interface with DVCSes and web hooks
* Completely static output, so easy to host anywhere !

Features
--------

Pelican currently supports:

* blog articles and pages
* comments, via an external service (disqus). Please notice that while
  it's useful, it's an external service, and you'll not manage the
  comments by yourself. It could potentially eat your data.
* theming support (themes are done using `jinja2 <http://jinjna.pocoo.org>`_)
* PDF generation of the articles/pages (optional).
* Translations
* Syntactic recognition

Have a look to `the documentation <http://alexis.notmyidea.org/pelican/>`_ for
more informations.

Why the name "Pelican" ?
------------------------

Heh, you didn't noticed? "Pelican" is an anagram for "Calepin" ;)

Source code
-----------

You can access the source code via git on http://github.com/ametaireau/pelican/

If you feel hackish, have a look to the `pelican's internals explanations
<http://alexis.notmyidea.org/pelican/internals.html>`_.

Feedback / Contact us
=====================

If you want to see new features in Pelican, dont hesitate to tell me, to clone
the repository, etc. That's open source, dude!

Contact me at "alexis at notmyidea dot org" for any request/feedback! You can
also join the team at `#pelican on irc.freenode.org 
<irc://irc.freenode.net/pelican>`_ 
(or if you don't have any IRC client, using `the webchat
<http://webchat.freenode.net/?channels=pelican&uio=d4>`_)
for quick feedback.
